@@ -93,9 +93,7 @@ def sql(key):
         'ReprotIdDisable': {'sql': "SELECT report_id From report WHERE is_share_allowed = 0;", 'database': 'AnyRobot'},
         'ReprotName': {'sql': "SELECT `name` From report ;", 'database': 'AnyRobot'},
         'ReprotType': {'sql': "SELECT `type` From report ;", 'database': 'AnyRobot'},
-        'CorrelationSearchesId': {'sql': "SELECT `id` From correlate_search ;", 'database': 'AnyRobot'},
-        'DataTableId': {'sql': 'select id from Kibana where title="文件采集详情";', 'database': 'AnyRobot'},
-
+        'CorrelationSearchesId': {'sql': "SELECT `id` From correlate_search ;", 'database': 'AnyRobot'}
     }
 
     if switcher.get(key) is not None:
