@@ -6,7 +6,7 @@ import random
 import jsonpath
 import requests,json
 from aishu import setting
-
+from aishu.public import urlJoin
 
 class inputs(object):
     """
@@ -17,7 +17,8 @@ class inputs(object):
 
         :return:
         """
-        url = "http://{ip}/etl/input".format(ip=setting.host)
+        path = '/etl/input'
+        url = urlJoin.url(path)
         portList = [port for port in range(20010, 20100)]
         portList.append(162)
         portList.append(514)
@@ -47,10 +48,5 @@ class inputs(object):
 
 
 if __name__ == '__main__':
-    setting.host = "10.4.108.128"
-    setting.database = 'AnyRobot'
-    setting.password = 'eisoo.com'
-    setting.port = 30006
-    setting.user = 'root'
     date = inputs().createarPortId()
     print(date)
\ No newline at end of file
