@@ -4,4 +4,4 @@ class date(object):
         return 'ar.test@aishu.cn'
 
     def getMailPass(self):
-        return 'Eisoo.com123'
\ No newline at end of file
+        return 'artest`123'
\ No newline at end of file
