@@ -1,5 +1,5 @@
 from aishu import setting
-from aishu.datafaker.profession.entity import name, switch, ip, timestamp, ml, kai, objectManager, index, agent ,id ,port, DataManage
+from aishu.datafaker.profession.entity import name, switch, ip, timestamp, ml, kai, objectManager, index, agent ,id ,port, DataManage, databaseInfo
 from aishu.datafaker.profession.entity import zx,testMail, arPort
 from aishu.datafaker.profession.entity.ParaDateFiled import ParaDateFiledServer
 from aishu.datafaker.profession.entity.RetrievesAssociated import ParaDateAnyRobotServer
@@ -89,7 +89,12 @@ def filed(key,inquire=[]):
         'now_times': ParaDateFiledServer().now_time,
         'five_feature_times': ParaDateFiledServer().five_feature_time,
         'getlocalhostIp':ip.date().getlocalhostIp,
-        'getNowYear':timestamp.date().getNowYear
+        'getNowYear':timestamp.date().getNowYear,
+        'getSelfDatabase':databaseInfo.data().getSelfDatabase,
+        'getSelfDatabasePassword':databaseInfo.data().getSelfDatabasePassword,
+        'getSelfDatabaseUser':databaseInfo.data().getSelfDatabaseUser,
+        'getSelfDatabaseUrl':databaseInfo.data().getSelfDatabaseUrl,
+        'getSelfDatabasePort':databaseInfo.data().getSelfDatabasePort
     }
 
     switcher = SERVICE_KPI_
@@ -99,10 +104,5 @@ def filed(key,inquire=[]):
         return False
 
 if __name__ == '__main__':
-    setting.host = ""
-    setting.database = ''
-    setting.password = ''
-    setting.port = 3306
-    setting.user = ''
-    date = filed("")
+    date = filed("getSelfDatabasePassword")
     print(date)
\ No newline at end of file
